<?php

namespace App\Model;

use Nette;
use Nette\Utils\DateTime;

/**
 * Class for handling activities related to meetings
 * @package App\Model
 */
class MeetingFacade {
    use Nette\SmartObject;

    private Nette\Database\Explorer $database;

    public function __construct(Nette\Database\Explorer $database) {
        $this->database = $database;
    }

    /**
     * @param int $id
     * @return Nette\Database\Table\ActiveRow|null
     */
    public function getMeeting(int $id){
        return $this->database->table('MEETING')->get($id);
    }

    /**
     * Function returns meetings linked with given structure
     * @param $linking linked structure (mentor = mentor user)
     * @param $id identifier of linked structure
     * @return Nette\Database\Table\Selection|null
     */
    public function getMeetingsLinkedWith($linking, $id) {
        if($linking == 'mentor') {
            return $this->database->table('MEETING')->select('MEETING.datetime, MEETING.info, MEETING.place, 
            MEETING.project_id, project_id.assignment.name AS assignment_name')->where('linking', 'mentor')
                ->where('user_id', $id)->order('datetime DESC')->limit(7);
        }

        return null;
    }

    /**
     * Function creates new meeting record
     * @param string $datetime
     * @param string $room
     * @param string $person
     * @param string $comment
     * @param int $project
     * @param null $linking
     * @return Nette\Database\Table\ActiveRow|null
     * @throws \Exception
     */
    public function addMeeting(string $datetime, string $room,
                               string $person, string $comment, int $project, $linking = null):Nette\Database\Table\ActiveRow|null {

        if($linking == 'null') $linking = null;

        return $this->database->table('MEETING')->insert([
            'datetime' => DateTime::from( strtotime($datetime)),
            'place' => $room,
            'person' => $person,
            'info' => $comment,
            'project_id' => $project,
            'linking' => $linking

        ]);
    }
}