<?php

namespace App\Presenters;

use App\Model\AssignmentManager;
use App\Model\Constants;
use App\Model\InterestManager;
use App\Model\MailManager;
use App\Model\RoleManager;
use App\Model\TeamManager;

/**
 * Presenter class to handle requests to AssignmentAssignmentToTeam page
 */
class AssignmentAssignmentToTeamManagementPresenter extends BasePresenter {

    protected AssignmentManager $assignmentManager;
    protected InterestManager $interestManager;

    public function __construct(AssignmentManager $assignmentManager, InterestManager $interestManager) {
        parent::__construct();

        $this->assignmentManager = $assignmentManager;
        $this->interestManager = $interestManager;
    }

    public function renderDefault() {

        $teams = $this->database->table('TEAM')->where(":PROJECT.id", null);
        // $teams = $this->database->table('TEAM');

        $assignments = $this->database->table('ASSIGNMENT')->where(":PROJECT.id", null);
        // $assignments = $this->database->table('ASSIGNMENT');

        $interests = $this->database->table('ASSIGNMENT_INTEREST')->where('state', Constants::$ASSIGNMENT_INTEREST_STATUS_EXPRESSED);

        $data = array();

        foreach ($assignments as $assignment) {
            $data[$assignment->id] = array();
        }

        foreach ($interests as $interest) {
            $data[$interest->assignment->id][$interest->team->id] = $interest;
        }

        $this->template->teams = $teams;
        $this->template->assignments = $assignments;

        $this->template->data = $data;
    }

    public function handleAssignTeam($assignmentId, $teamId) {
        $interest = $this->interestManager->getInterest($assignmentId, $teamId);

        if(!$interest) {
            $this->flashMessage('Chyba;Chyba ve zpracování požadavku', 'bg-danger');
            return;
        }

        $this->assignmentManager->assignTeamByInterest($interest);

        $this->loggerManager->get('default')->notice('The assignment was assigned to the team', [

            'user_info' => $this->getUser()->getIdentity()->getData(),
            'team_id' => $interest->team->id,
            'team_name' => $interest->team->name,
            'team_leader_login' => $interest->team->student->login,
            'assignment_id' => $interest->assignment->id,
            'assignment_topic' => $interest->assignment->name,
        ]);
        $this->flashMessage('Úspěch;Týmu bylo přiděleno zadání.', 'bg-success');
    }

    public function canAccessPage(): bool {
        if(!$this->user->isLoggedIn()) {
            return false;
        } else if($this->user->isInRole(RoleManager::$ROLE_GARANT)) {
            return true;
        }
        return false;
    }

}