<?php

declare(strict_types=1);

namespace App\Presenters;

use App\Model\AssignmentManager;
use App\Model\InterestManager;
use App\Model\ProjectManager;
use App\Model\RoleManager;
use Nette;

/**
 * Presenter class to handle requests to page with assignments without team
 */
class AssignmentsWithoutTeamPresenter extends BasePresenter {

    private ProjectManager $projectManager;
    private InterestManager $interestManager;
    private AssignmentManager $assignmentManager;

    public function __construct(ProjectManager $projectManager,
                                InterestManager $interestManager,
                                AssignmentManager $assignmentManager) {
        parent::__construct();

        $this->projectManager = $projectManager;
        $this->interestManager = $interestManager;
        $this->assignmentManager = $assignmentManager;
    }

    public function renderDefault(int $id = -1) {
        if($id == -1) {
            $id = $this->user->getId();
        }

        $this->template->mentor = $this->database->table('USER')->get($id);

        $this->loggerManager->get('default')->info("Homepage is loaded",["user_id"=>$this->getUser()->getId()]);

        $this->template->mentoredAssignmentsNotAssigned = $this->assignmentManager
            ->getMentoredAssignmentsWithoutTeamAndInterest($id);

        $this->template->mentoredAssignmentsInterests = $this->interestManager->getInterestsByMentor($id)->order('mentor_evaluation ASC');
    }

    public function handleEvaluateInterest($teamId, $assignmentId, $value) {

        $assignment = $this->assignmentManager->getAssignment(intval($assignmentId));

        if($this->assignmentManager->getMentorUser($assignment)->id != $this->getUser()->getId() && !$this->user->isInRole(RoleManager::$ROLE_GARANT)) {
            $this->flashMessage("Chyba;Na vyžádanou akci nemáte potřebná oprávnění ", "bg-danger");
            return;
        }

        $interest = $this->interestManager->getInterest($assignmentId, $teamId);

        $returnCode = $this->interestManager->evaluate($teamId, $assignmentId, $value);

        if($returnCode >= 0) {
            $this->flashMessage("Úspěch;Ohodnocení bylo uděleno", "bg-success");
            $this->loggerManager->get('default')->notice('The mentor evaluated the interest in the assignment', [
                'user_identity' => $this->getUser()->getIdentity()->getData(),
                'interest_id' => $interest->id,
                'interest_weight' => $interest->weight,
                'assignment_id' => $interest->assignment->id,
                'assignment_name' => $interest->assignment->name,
                'team_id' => $interest->team->id,
                'team_name' => $interest->team->name,
                'evaluation' => $interest->mentor_evaluation,
            ]);

        } else if($returnCode < 0) {
            $this->flashMessage("Chyba;Při zpracování požadavku se vyskytla validační chyba", "bg-warning");
        }
    }

    public function canAccessPage(): bool {
        if(!$this->user->isLoggedIn()) {
            return false;
        } else if($this->user->isInRole(RoleManager::$ROLE_MENTOR) || $this->getUser()->isInRole(RoleManager::$ROLE_GARANT)) {
            return true;
        }
        return false;
    }
}