<?php

namespace App\Presenters;

use App\Model\MailManager;
use App\Model\RoleManager;
use App\Model\TeamManager;
use Nette\Utils\DateTime;
use Nette\Utils\FileSystem;

/**
 * Presenter class to handle requests to page with log management
 */
class LogManagementPresenter extends BasePresenter {

    public function __construct() {
        parent::__construct();
    }

    public function renderDefault() {

        $this->template->isLog = false;

        $this->template->logName = $this->getParameter('log');
        if($this->template->logName) {
            $this->template->isLog = true;

            $fileContent = file(FileSystem::joinPaths('../log/syslog', $this->template->logName));
            $parsed = array();

            foreach($fileContent as $row) {

                $words = explode(' ', trim($row));
                $time = DateTime::createFromFormat("\[Y-m-d\TH:i:s.uP\]", $words[0]);
                $channelLevel = explode('.', str_replace(":", "", $words[1]));

                $message = "";
                $i = 0;
                for($i = 2; $i < count($words) - 2; $i += 1) {
                    if(!str_contains($words[$i], '{')) {
                        $message .= $words[$i] . ' ';
                    } else {
                        break;
                    }
                }

                $data = "";
                for(; $i < count($words) - 1; $i += 1) {
                    $data .= $words[$i] . ' ';
                }


                $message = trim($message);

                $parsed[] = [
                    'time' => $time,
                    'message' => $message,
                    'channel' => $channelLevel[0],
                    'level' => $channelLevel[1],
                    'data' => $data,
                ];

            }

            $this->template->logContent = $parsed;
        }


        $this->template->periods = $this->database->table('PERIOD');

        $content = scandir('../log/syslog');

        unset($content[0]);
        unset($content[1]);

        $sizes = array();

        foreach ($content as $con) {
            $sizes[] = filesize(FileSystem::joinPaths('../log/syslog', $con));
        }

        $this->template->logs = $content;
    }

    public function handleDownloadLogFile(string $logName) {

        if(!$logName) {
            $this->flashMessage('Chyba;Soubor se nepodařilo stáhnout.', 'bg-danger');
            $this->redirect('this');
        }

        $logPath = FileSystem::joinPaths('../log/syslog/', $logName);

        $fileSize = filesize($logPath);

        header('Content-length: ' . $fileSize);
        header('Content-type: text/plain');
        header('Content-disposition: attachment; filename=' . $logName);

        flush();
        readfile($logPath);
        if(ob_get_length() > 0) {
            ob_clean();
        }
        flush();

        $this->loggerManager->get('default')->info('The log file has been downloaded',
            ['user_id' => $this->getUser()->getId(), 'user_identity' => $this->getUser()->getIdentity()->getData()]);
        exit;
    }

    public function canAccessPage(): bool {
        if(!$this->user->isLoggedIn()) {
            return false;
        } else if($this->user->isInRole(RoleManager::$ROLE_GARANT)) {
            return true;
        }
        return false;
    }
}