<?php

declare(strict_types=1);

namespace App\Presenters;

use App\Model\ProjectManager;
use App\Model\RoleManager;
use Nette;
use Ublaboo\DataGrid\DataGrid;

/**
 * Presenter class to handle requests to page with projects history
 */
class MentoredProjectsHistoryPresenter extends BasePresenter {

    private ProjectManager $projectManager;

    public Nette\Database\Explorer $database;

    public function __construct(ProjectManager $projectManager, Nette\Database\Explorer $database) {
        parent::__construct();

        $this->database = $database;
        $this->projectManager = $projectManager;
    }

    public function renderDefault() {

        //TODO: Test if user has permission to see this page
        $this->loggerManager->get('default')->info("Mentored projects page is loaded",["user_id"=>$this->getUser()->getId()]);

    }

    public function createComponentSimpleGrid($name) {
        $grid = new DataGrid($this, $name);

        //$grid->setDataSource($this->database->table('ASSIGNMENT', 'a')->select("ASSIGNMENT.id,
        // ASSIGNMENT.name, CONCAT(creator.firstname, ' ', creator.lastname) AS creator_name, period.label"));
        $grid->setDataSource($this->database->table('PROJECT')
            ->select("PROJECT.id, team.name AS team_name, assignment.id AS assignment_id, assignment.name AS assignment_name, assignment.period.label AS period_label")
            ->where("assignment.user_id", $this->getUser()->getId()));

        $grid->setTemplateFile(__DIR__ . '/templates/DataGrid/basicTemplate.latte');

        //$grid->addColumnText('PROJECT.id', 'ID')->setSortable();
        //$grid->addColumnText('name', 'Název');
        $grid->addColumnLink('assignment_name', 'Zadání', 'Assignment:show', 'assignment_name', ['id'])->setSortable();
        //$grid->addColumnText('label', 'Období');
        //$grid->addColumnText('creator_name', 'Zadavatel');
        //$grid->addColumnText('assignment_name', 'Zadání');
        $grid->addColumnText('team_name', 'Tým');
        $grid->addColumnText('period_label', 'Období');


    }

    public function canAccessPage(): bool {
        if(!$this->user->isLoggedIn()) {
            return false;
        } else if($this->user->isInRole(RoleManager::$ROLE_MENTOR)) {
            return true;
        }

        return false;
    }
}