<?php

namespace App\Presenters;

use App\Components\PasswordRecoverForm;
use App\Model\UserManager;
use App\Model\Utils;
use Contributte\Monolog\LoggerManager;
use Nette;
use Nette\Application\UI\Form;
use Nette\Security\AuthenticationException;
use Nette\Utils\ArrayHash;

/**
 * Presenter class to handle requests to page with password recovery
 */
class RecoverPresenter extends Nette\Application\UI\Presenter {

    private UserManager $userManager;
    private PasswordRecoverForm $passwordRecoverForm;
    private LoggerManager $loggerManager;

    public function __construct(UserManager $userManager, PasswordRecoverForm $passwordRecoverForm, LoggerManager $loggerManager) {
        parent::__construct();
        $this->userManager = $userManager;
        $this->passwordRecoverForm = $passwordRecoverForm;
        $this->loggerManager = $loggerManager;
    }

    public function startup() {
        parent::startup();
        if($this->user->isLoggedIn()) {
            $this->redirect('Homepage:');
        }

    }

    public function beforeRender() {
        parent::beforeRender();

        $token = $this->getParameter('token');

        if(!$this->userManager->isRecoveryTokenValid($token)) {
            $this->loggerManager->get('default')->info('An invalid recovery token was used',
                ['ip_addr' => UserManager::getIp(), 'token' => $token]);
            $this->flashMessage('Chyba;Autentizační token je neplatný nebo jeho platnost vypršela.', 'bg-danger');
            $this->redirect('Sign:forget');
        }
    }

    public function renderDefault() {
        $token = $this->getParameter('token');

        $this->template->token = $token;
    }

    protected function createComponentPasswordRecoverForm(): Form {

        $form = $this->passwordRecoverForm->create($this->getParameter('token'));
        $user = $this->userManager->getUserByRecoverToken($this->getParameter('token'));

        $form->onSuccess[] = function () use ($user) {
            if($user != null) {
                $this->loggerManager->get('default')->info('Password recovery was successful',
                    ['ip_addr' => UserManager::getIp(), 'token' => $this->getParameter('token'), 'user-id' => $user['id'],
                        'user_login' => $user['login']]);
            }
            $this->flashMessage('Úspěch;Změna hesla proběhla úspěšte. Přihlašte se prosím.', 'bg-success');
            $this->redirect("Sign:in");
        };
        $form->onError[] = function() {
            //$this->flashMessage("Chyba;Přihlášení se nezdařilo. Zkontrolujte kombinaci přihlašovacího jmena a hesla", 'bg-warning');
        };
        return $form;
    }

}