<?php

namespace App\Presenters;

use App\Components\ProfileAddForm;
use App\Components\TeamRoleAddForm;
use App\Model\MailManager;
use App\Model\RoleManager;
use App\Model\TeamManager;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;

/**
 * Presenter class to handle requests to page with tags management
 */
class TagsManagementPresenter extends BasePresenter {

    protected TeamRoleAddForm $teamRoleAddForm;
    protected ProfileAddForm $profileAddForm;

    public function __construct(TeamRoleAddForm $teamRoleAddForm, ProfileAddForm $profileAddForm) {
        parent::__construct();

        $this->teamRoleAddForm = $teamRoleAddForm;
        $this->profileAddForm = $profileAddForm;
    }

    public function renderDefault() {
        $this->template->tags = $this->database->table('TAG');
        $this->template->roles = $this->database->table('TEAM_ROLE');
    }

    public function renderEditTag(int $id) {}

    public function renderEditTeamRole(int $id) {}

    public function createComponentTeamRoleAddForm():Form {

        if($this->getAction() == "editTeamRole") {
            $form = $this->teamRoleAddForm->create(intval($this->getParameter('id')));
            $form->onSuccess[] = function(Form $form, ArrayHash $values) {
                $this->flashMessage("Úspěch;Úprava štítku byla úspěšná.", "bg-success");
                $this->loggerManager->get('default')->info('The team role has been modified', [
                    'user_identity' => $this->getUser()->getIdentity()->getData(),
                    'role_id' => $values['roleId'],
                    'role_label' => $values['label'],
                ]);
                $this->redirect('TagsManagement:');
            };
        } else {
            $form = $this->teamRoleAddForm->create();
            $form->onSuccess[] = function(Form $form, ArrayHash $values) {
                $this->loggerManager->get('default')->info('The team role has been created', [
                    'user_identity' => $this->getUser()->getIdentity()->getData(),
                    'role_label' => $values['label'],
                ]);
                $this->flashMessage("Úspěch;Přidání štítku bylo úspěšné.", "bg-success");
                $this->redirect('TagsManagement:');
            };
        }

        return $form;
    }

    public function createComponentProfileAddForm():Form {

        if($this->getAction() == "editTag") {
            $form = $this->profileAddForm->create(intval($this->getParameter('id')));
            $form->onSuccess[] = function(Form $form, ArrayHash $values) {
                $this->loggerManager->get('default')->info('The profile tag has been modified', [
                    'user_identity' => $this->getUser()->getIdentity()->getData(),
                    'tag_id' => $values['tagId'],
                    'tag_label' => $values['label'],
                ]);
                $this->flashMessage("Úspěch;Editace štítku byla úspěšná.", "bg-success");
                $this->redirect('TagsManagement:');
            };
        } else {
            $form = $this->profileAddForm->create();
            $form->onSuccess[] = function(Form $form, ArrayHash $values) {
                $this->loggerManager->get('default')->info('The profile tag has been created', [
                    'user_identity' => $this->getUser()->getIdentity()->getData(),
                    'tag_label' => $values['label'],
                ]);
                $this->flashMessage("Úspěch;Přidání štítku bylo úspěšné.", "bg-success");
                $this->redirect('TagsManagement:');
            };
        }

        return $form;
    }

    public function canAccessPage(): bool {
        if(!$this->user->isLoggedIn()) {
            return false;
        } else if($this->user->isInRole(RoleManager::$ROLE_GARANT)) {
            return true;
        }
        return false;
    }
}