<?php

namespace App\Components;

use App\Model\DefenceManager;
use App\Model\TeamManager;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use Nette\Utils\DateTime;

/**
 * Form component class for creating project defence record
 * @package App\Components
 */
class DefenceAddForm {

    protected TeamManager $teamManager;
    protected DefenceManager $defenceManager;

    /**
     * Component constructor
     * @param TeamManager $teamManager
     * @param DefenceManager $defenceManager
     */
    public function __construct(TeamManager $teamManager,
                                DefenceManager $defenceManager) {
        $this->teamManager = $teamManager;
        $this->defenceManager = $defenceManager;

    }

    /**
     * Factory function for creating defence record creation form
     * @param $teamId the access identifier for restricting access
     * @return resulted Form instance
     */
    public function create($teamId):Form {

        $form = new Form();

        $form->addInteger('termNumber', 'Číslo pokusu')
            ->setRequired('Položka musí být vyplněna.')
            ->setDefaultValue(1)
            ->setHtmlAttribute("class","form-control");

        $form->addText('termDate', 'Datum obhajoby')
            ->setRequired('Položka musí být vyplněna.')
            ->setHtmlType('date')
            ->setDefaultValue((new DateTime())->format('Y-m-d'))
            ->setHtmlAttribute("class","form-control");
        $form->addSelect('termResult', 'Výsledek obhajoby', [
            '1' => 'Splněno',
            '2' => 'Nesplněno',
            '0' => 'Nespecifikováno',
        ])
        ->setHtmlAttribute('class', 'form-control')
        ->setRequired('Položka musí být vyplněna.');

        $form->addHidden('teamId', $teamId);

        $form->addSubmit('send');

        $form->onSuccess[] = [$this, 'addDefence'];

        return $form;

    }

    /**
     * Function that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function addDefence(Form $form, ArrayHash $values) {
        $this->defenceManager->createDefence($values['teamId'], $values['termNumber'], $values['termDate'], $values['termResult']);
    }

}