<?php

namespace App\Components;

use App\Model\PeriodManager;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;

/**
 * Form component class for creating new period cycle for TSP
 * @package App\Components
 */
class PeriodCreationForm {

    protected PeriodManager $periodManager;

    /**
     * Component constructor
     * @param PeriodManager $periodManager
     */
    public function __construct(PeriodManager $periodManager) {
        $this->periodManager = $periodManager;
    }

    /**
     * Factory function for creating period creation form
     * @return Form
     */
    public function create():Form {

        $form = new Form();

        $form->addText('name','Název nového ročníku')
            ->setRequired('Položka musí být vyplněna')
            ->setHtmlAttribute('class', 'form-control');

        $form->addSubmit('send');

        $form->onSuccess[] = [$this, 'periodCreate'];


        return $form;
    }

    /**
     * Function that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function periodCreate(Form $form, ArrayHash $values) {
        $this->periodManager->createPeriod($values['name']);
    }
}