<?php

namespace App\Components;

use App\Model\TagManager;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;

/**
 * Form component class for creating new (or editing) tag as profile badge
 */
class ProfileAddForm extends Form {

    protected TagManager $tagManager;

    /**
     * Component constructor
     * @param TagManager $tagManager
     */
    public function __construct(TagManager $tagManager) {
        parent::__construct();
        $this->tagManager = $tagManager;
    }

    /**
     * Factory function for creating profile badge tag
     * @param int $tagId tag identifier for editing purpose (if 0 creating new one)
     * @return Form
     * @throws \Exception
     */
    public function create(int $tagId = 0):Form {

        $defaults = [
            'name' => '',
            'canUse' => true,
        ];

        $form = new Form();

        if($tagId != 0) {
            $tag = $this->tagManager->getTag($tagId);

            if($tag == null) {
                throw new \Exception("Cannot create form with invalid id");
            }

            $defaults = [
                'name' => $tag->name,
                'canUse' => (boolean) $tag->applicable,
            ];
        }

        $form->addText('label', 'Název profilu')->setRequired('Náázev profilu musí být vyplněn.')
            ->setHtmlAttribute('class', 'form-control')->setDefaultValue($defaults['name']);


        $form->addCheckbox('canUse', 'Použitelné')->setDefaultValue('checked')
        ->setHtmlAttribute('class', 'form-check-input')->setDefaultValue($defaults['canUse']);

        if($tagId != 0) {
            $form->addHidden('tagId', $tagId);
        }

        $form->addSubmit('send');

        if($tagId == 0) {
            $form->onSuccess[] = [$this, 'addProfileTag'];
        } else {
            $form->onSuccess[] = [$this, 'editProfileTag'];
        }
        return $form;
    }

    /**
     * Function that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function addProfileTag(Form $form, ArrayHash $values) {
        $this->tagManager->createTag($values['label'], $values['canUse']);
    }

    /**
     * Function that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function editProfileTag(Form $form, ArrayHash $values) {
        $this->tagManager->editTag($values['tagId'], $values['label'], $values['canUse']);
    }
}