<?php

namespace App\Components;

use App\Model\TeamManager;
use App\Model\TagManager;
use App\Model\UserManager;
use Nette\Application\AbortException;
use Nette\Application\UI\Form;
use Nette\Database\Explorer;
use Nette\Security\AuthenticationException;
use Nette\Security\User;
use Nette\Utils\ArrayHash;

/**
 * Form component class for editing team profile information
 * @package App\Components
 */
class TeamAdvancesForm extends Form {
    protected TeamManager $teamManager;
    protected TagManager $tagManager;

    /**
     * Component constructor
     * @param TeamManager $teamManager
     * @param TagManager $tagManager
     */
    public function __construct(TeamManager $teamManager, TagManager $tagManager) {
        parent::__construct();
        $this->teamManager = $teamManager;
        $this->tagManager= $tagManager;
    }

    /**
     * Factory function for creating team edit profile form
     * @param int $teamId edited team identifier
     * @return Form resulted Form instance
     */
    public function create(int $teamId = 0) {
        $values = $this->tagManager->getAllApplicableTags();
        $defaults = [];
        $form = new Form();
        if ($teamId != 0) {
            $defaults = $this->teamManager->getTeamAdvances($teamId);
        }
        $form->addMultiSelect("advances", "Znalosti a dovednosti", $values)
            ->setHtmlAttribute('class="selectpicker form-control" multiple data-live-search="true" title="Vyberte prosím předvolbu"')
            ->setHtmlAttribute("multiple=multiple")
            ->setHtmlAttribute("style= width:100%")->setDefaultValue(array_flip($defaults));
        $form->addHidden("teamId",$teamId);
        $form->addSubmit('save', 'Potvrdit změny');
        $form->addButton('cancel', 'Zrušit');
        //$form->onValidate[] = [$this, 'validateForm'];
        $form->onSuccess[] = [$this, 'saveForm'];
        return $form;
    }

    /**
     * Function that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function saveForm(Form $form, ArrayHash $values) {
        try {
            $this->teamManager->updateTeamSkills($values['teamId'],$values['advances']);
        }  catch (AbortException $e) {

        }
    }
}